from gcandle.utils.DatabaseClient import DatabaseClient


DB_CLIENT = DatabaseClient()
